@@ -1,29 +1,33 @@
-import tempfile
 import json
 import random
+import tempfile
+
 from accession.backends import GCBackend
 
 
-def filter_outputs_by_path(path):
-    bucket = path.split('gs://')[1].split('/')[0]
-    google_backend = GCBackend(bucket)
-    filtered = [file
-                for file
-                in list(google_backend.bucket.list_blobs())
-
-                if path.split('gs://')[1]
-                in file.id
-                and '.json' in file.id]
+def filter_outputs_by_path(path, backend=None):
+    bucket = path.split("gs://")[1].split("/")[0]
+    if not backend:
+        google_backend = GCBackend(bucket)
+    else:
+        google_backend = backend
+    filtered = [
+        file
+        for file in list(google_backend.bucket.list_blobs())
+        if path.split("gs://")[1] in file.id and ".json" in file.id
+    ]
 
     for file in filtered:
-        file.download_to_filename(file.public_url.split('/')[-1])
+        file.download_to_filename(file.public_url.split("/")[-1])
+
+    return filtered
 
 
 # Python equivalent of WDL's write_json
 # for testing purposes
 def write_json(json_data):
     temp_file = tempfile.NamedTemporaryFile(delete=False)
-    with open(temp_file.name, 'a') as file:
+    with open(temp_file.name, "a") as file:
         json.dump(json_data, file)
     return temp_file.name
 
@@ -38,7 +42,7 @@ def mutate_digits(md5sum_string):
                 continue
             md5sum_list[i] = str((int(character) + 1) % 10)
         print(md5sum_list)
-    return ''.join(md5sum_list)
+    return "".join(md5sum_list)
 
 
 def string_to_number(string):
@@ -46,8 +50,8 @@ def string_to_number(string):
         return string
     try:
         return int(string)
-    except:
+    except Exception:
         try:
             return float(string)
-        except:
+        except Exception:
             return string
